class x87 {
    constructor(parm__2: () => Base[] = function named__3() {
        return [
            d1,
            d2
        ];
    }){
    }
}
class x90 {
    constructor(parm__4: {
        () : Base[];
    } = function named__5() {
        return [
            d1,
            d2
        ];
    }){
    }
}
